@@ -78,8 +78,8 @@ setReplaceMethod("ctrlfl", signature = (object = "optsol_robAna"),
 
 setMethod("plot", signature(x = "optsol_robAna", y = "missing"),
           function(x, y,
-                   xlab = "Control Flux",
-                   ylab = "Objective Function",
+                   xlab = paste("Control Flux:", react_id(ctrlr(x))),
+                   ylab = paste("Objective Function:", obj_func(x)),
                    type = "b",
                    pch = 20,
                    fillColorBg = "grey",
